Crate htmlrs

Crate htmlrs 

Macros

html
view
The view macro uses RSX (like JSX, but Rust!) It follows most of the same rules as HTML, with the following differences:

Traits

IntoView
Converts the value into a View.

Type Aliases

Children
The most common type for the children property on components, which can only be called once.

Attribute Macros

component
Annotates a function so that it can be used with your template as a Leptos <Component/>.